package com.suliang.common.base.activity

import android.os.Bundle
import android.view.LayoutInflater
import androidx.appcompat.app.AppCompatActivity
import androidx.lifecycle.ViewModelProvider
import androidx.lifecycle.ViewModelProviders
import androidx.viewbinding.ViewBinding
import com.suliang.common.extension.initBinding
import com.suliang.common.util.ActivityStackManager
import java.lang.reflect.ParameterizedType

/**
 * 基类Activity
 */
abstract class BaseActivity<VB : ViewBinding> : AppCompatActivity() {

    lateinit var binding: VB

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        addStackManager()
        initFirst()
        initActivity(savedInstanceState)    }

    protected open fun initFirst() {
        setLayoutBefore()
        binding = initBinding(layoutInflater)
        setContentView(binding.root)
        initStatusBar()
        setLayoutAfter()
    }


    /**
     * 状态栏初始化方法
     */
    open fun initStatusBar() {
//        statusBarOnly {
//            fitWindow = true
//            color = Color.WHITE
//            light = true
//        }
    }

    override fun onDestroy() {
        super.onDestroy()
        ActivityStackManager.removeActivity(this)
    }


    private fun addStackManager() {
        ActivityStackManager.addActivity(this)
    }

    /** 布局前操作 ： 空实现 */
    public open fun setLayoutBefore() {

    }

    /**
     * 布局后操作：空实现
     */
    public open fun setLayoutAfter() {

    }

    /**
     * onCreate中给与app中用户的具体实现
     * @param savedInstanceState Bundle?
     */
    abstract fun initActivity(savedInstanceState: Bundle?)

//    @SuppressWarnings("unchecked")
//    fun initBinding(inflater: LayoutInflater): VB {
//        val vbClass =
//            (javaClass.genericSuperclass as ParameterizedType).actualTypeArguments.filterIsInstance<Class<VB>>()
//        val inflate = vbClass[0].getDeclaredMethod("inflate", LayoutInflater::class.java)
//        return inflate.invoke(null, inflater) as VB
//    }

}