package com.suliang.common.base.fragment

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.databinding.ViewDataBinding
import androidx.fragment.app.Fragment
import com.suliang.common.extension.initBinding
/**
 * Fragment ViewBinding基类，封装ViewDataBinding
 * @property VB : ViewDataBinding
 * @property VM:  ViewModel
 */
abstract class BaseFragment<VB: ViewDataBinding>: Fragment(){
    lateinit var binding: VB

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        binding = initBinding(inflater,container)
        return super.onCreateView(inflater, container, savedInstanceState)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        initFirst()
        initFragment()
    }

    abstract fun initFirst()
    abstract fun initFragment()

}